import{R as h,ac as o,ad as u,V as $,j as b,q as g,s as c,X as N,aq as f,bx as _,l as x,h as j,w as C,a1 as v,H as O,n as E,P as p,a2 as w,a5 as S}from"./index-DlVEHVJB.js";const K=h({tag:{type:String,default:"div"},span:{type:Number,default:24},offset:{type:Number,default:0},pull:{type:Number,default:0},push:{type:Number,default:0},xs:{type:u([Number,Object]),default:()=>o({})},sm:{type:u([Number,Object]),default:()=>o({})},md:{type:u([Number,Object]),default:()=>o({})},lg:{type:u([Number,Object]),default:()=>o({})},xl:{type:u([Number,Object]),default:()=>o({})}}),P=Symbol("rowContextKey"),k=b({name:"ElCol"}),q=b({...k,props:K,setup(d){const t=d,{gutter:n}=g(P,{gutter:c(()=>0)}),a=N("col"),m=c(()=>{const e={};return n.value&&(e.paddingLeft=e.paddingRight=`${n.value/2}px`),e}),i=c(()=>{const e=[];return["span","offset","pull","push"].forEach(s=>{const l=t[s];f(l)&&(s==="span"?e.push(a.b(`${t[s]}`)):l>0&&e.push(a.b(`${s}-${t[s]}`)))}),["xs","sm","md","lg","xl"].forEach(s=>{f(t[s])?e.push(a.b(`${s}-${t[s]}`)):_(t[s])&&Object.entries(t[s]).forEach(([l,r])=>{e.push(l!=="span"?a.b(`${s}-${l}-${r}`):a.b(`${s}-${r}`))})}),n.value&&e.push(a.is("guttered")),[a.b(),e]});return(e,y)=>(j(),x(w(e.tag),{class:E(p(i)),style:O(p(m))},{default:C(()=>[v(e.$slots,"default")]),_:3},8,["class","style"]))}});var B=$(q,[["__file","col.vue"]]);const H=S(B);export{H as E,P as r};
